@@ -18,8 +18,7 @@
 #ifndef __COMMAND_H__
 #define __COMMAND_H__
 
-int cmd_exec(char *cmd);
-void cmd_init(FILE *f);
-void cmd_cleanup(FILE *f);
+int cmd_exec(char **argv);
+void cmd_init(const char *ifname, const char *ofname);
 
 #endif
