@@ -17,6 +17,6 @@
  */
 /* config.h: configuration macros */
 
-#define CFG_EDITOR "/usr/bin/vi"
+#define CFG_EDITOR "/usr/bin/sensible-editor"
 #define CFG_BUFSZ  1024
 #define CFG_PROMPT "rsrce> "
